@@ -80,7 +80,6 @@ if [ "$OPTION_PHONON" = yes ]; then TXSCOMPILEOPTIONS="$TXSCOMPILEOPTIONS PHONON
 if [ "$OPTION_TESTS" = no ]; then TXSCOMPILEOPTIONS="$TXSCOMPILEOPTIONS NO_TESTS=true"; fi
 case "$OPTION_DEBUG" in r|rel|release) TXSCOMPILEOPTIONS="$TXSCOMPILEOPTIONS  CONFIG-=debug CONFIG-=debug_and_release CONFIG+=release";; esac
 
-
 PATH=$QTDIR/bin:$PATH
 LD_LIBRARY_PATH=$QTDIR/lib:$LD_LIBRARY_PATH
 DYLD_LIBRARY_PATH=$QTDIR/lib:$DYLD_LIBRARY_PATH
@@ -89,13 +88,13 @@ export QTDIR PATH LD_LIBRARY_PATH DYLD_LIBRARY_PATH
 if [ "$SYSTEM" = 1 ] 
 then
   echo "Starting compilation"
-  $QMAKE -unix PREFIX=$PREFIX $TXSCOMPILEOPTIONS texstudio.pro
-  make
+  $QMAKE PREFIX=$PREFIX $TXSCOMPILEOPTIONS texstudio.pro
+  make -j 4
   echo "Compilation done"
   make install
   echo "Compilation and installation done"
   echo "Icons and desktop file can be found in the $PREFIX/share/texstudio directory"
-  # set the -spec option, if necessary. Ex : qmake -unix -spec linux-g++ PREFIX=$PREFIX texstudio.pro
+  # set the -spec option, if necessary. Ex : qmake -spec linux-g++ PREFIX=$PREFIX texstudio.pro
   exit 0
 fi
 
