@@ -52,7 +52,7 @@ QString getCommandLineViewPs();
 QString getCommandLineViewPdfExternal();
 QString getCommandLineGhostscript();
 
-CommandInfo::CommandInfo(): user(false), meta(false), rerunCompiler(false), guessFunc(0) {}
+CommandInfo::CommandInfo(): user(false), meta(false), rerunCompiler(false), guessFunc(nullptr) {}
 
 QString CommandInfo::guessCommandLine() const
 {
@@ -125,6 +125,11 @@ QString CommandInfo::getProgramName() const
 	return getProgramName(commandLine);
 }
 
+QString CommandInfo::getProgramNameUnquoted() const
+{
+    return getProgramNameUnquoted(commandLine);
+}
+
 ExpandingOptions::ExpandingOptions(const QFileInfo &mainFile, const QFileInfo &currentFile, const int currentLine): mainFile(mainFile), currentFile(currentFile), currentLine(currentLine), nestingDeep(0), canceled(false)
 {
 	override.removeAll = false;
@@ -258,7 +263,7 @@ QString BuildManager::resolvePaths(QString paths)
 		return paths;
 }
 
-BuildManager::BuildManager(): processWaitedFor(0)
+BuildManager::BuildManager(): processWaitedFor(nullptr)
 #ifdef Q_OS_WIN32
 	, pidInst(0)
 #endif
@@ -927,7 +932,10 @@ ExpandedCommands BuildManager::expandCommandLine(const QString &str, ExpandingOp
 				UtilsUi::txsInformation(tr("You have used txs:///command[... or txs:///command{... modifiers, but we only support modifiers of the form txs:///command/[... or txs:///command/{... with an slash suffix to keep the syntax purer."));
 				modifiers.clear();
 			}
-			if (options.override.removeAll) parameters.clear(), modifiers.clear();
+            if (options.override.removeAll) {
+                parameters.clear();
+                modifiers.clear();
+            }
 
 			bool user;
 			QString cmd = getCommandLine(cmdName, &user);
@@ -944,7 +952,8 @@ ExpandedCommands BuildManager::expandCommandLine(const QString &str, ExpandingOp
 			int space = cmd.indexOf(' ');
 			if (space == -1) space = cmd.size();
 			if (cmd.startsWith(TXS_CMD_PREFIX) && internalCommands.contains(cmd.left(space))) {
-				res.commands << CommandToRun(cmd + " " + parameters);
+                QStringList exp=parseExtendedCommandLine(cmd, options.mainFile, options.currentFile, options.currentLine);
+                res.commands << CommandToRun(exp.first()+" "+parameters);
 				res.commands.last().parentCommand = res.commands.last().command;
 				if (user) res.commands.last().flags |= RCF_CHANGE_PDF;
 				continue;
@@ -1060,7 +1069,7 @@ RunCommandFlags BuildManager::getSingleCommandFlags(const QString &subcmd) const
 #endif
 
 	if (viewerCommands.contains(subcmd) && !isAcrobat && singleViewerInstance) result |= RCF_SINGLE_INSTANCE;
-	return (RunCommandFlags)(result);
+    return static_cast<RunCommandFlags>(result);
 }
 
 bool BuildManager::hasCommandLine(const QString &program)
@@ -1246,7 +1255,7 @@ void BuildManager::registerOptions(ConfigManagerInterface &cmi)
 	cmi.registerOption("Tools/Max Expanding Nesting Deep", &maxExpandingNestingDeep, 10);
 	Q_ASSERT(sizeof(dvi2pngMode) == sizeof(int));
     cmi.registerOption("Tools/Dvi2Png Mode", reinterpret_cast<int *>(&dvi2pngMode), 3);
-	cmi.registerOption("Files/Save Files Before Compiling", reinterpret_cast<int *>(&saveFilesBeforeCompiling), (int)SFBC_ONLY_NAMED);
+    cmi.registerOption("Files/Save Files Before Compiling", reinterpret_cast<int *>(&saveFilesBeforeCompiling), static_cast<int>(SFBC_ONLY_NAMED));
 	cmi.registerOption("Preview/Remove Beamer Class", &previewRemoveBeamer, true);
 	cmi.registerOption("Preview/Precompile Preamble", &previewPrecompilePreamble, true);
 
@@ -1304,7 +1313,7 @@ void BuildManager::readSettings(QSettings &settings)
 			if (idx >= 0 && idx < userToolDisplayNames.length()) {
 				displayName = userToolDisplayNames[idx];
 			}
-			registerCommand(id, "", displayName, "", "", 0, true).commandLine = cmd;
+            registerCommand(id, "", displayName, "", "", nullptr, true).commandLine = cmd;
 		} else {
 			// default command
 			it.value().commandLine = cmd;
@@ -1327,10 +1336,10 @@ void BuildManager::readSettings(QSettings &settings)
 				if (import.startsWith(DEPRECACTED_TMX_INTERNAL_PDF_VIEWER)) {
 					import.remove(0, DEPRECACTED_TMX_INTERNAL_PDF_VIEWER.length() + 1);
 					cmd.commandLine = import;
-					commands.find("view-pdf").value().commandLine = CMD_VIEW_PDF_INTERNAL + " --embedded";
+                    //commands.find("view-pdf").value().commandLine = CMD_VIEW_PDF_INTERNAL + " --embedded";
 				} else {
 					cmd.commandLine = import;
-					commands.find("view-pdf").value().commandLine = CMD_VIEW_PDF_INTERNAL + " --embedded";
+                    //commands.find("view-pdf").value().commandLine = CMD_VIEW_PDF_INTERNAL + " --embedded";
 				}
 			} else cmd.commandLine = import;
 		}
@@ -1370,7 +1379,7 @@ void BuildManager::readSettings(QSettings &settings)
 		if (!deprecatedUserToolNames[i].endsWith("!!!CONVERTED!!!")) {
 			QString cmd = deprecatedUserToolCommands[i];
 			cmd.replace(DEPRECACTED_TMX_INTERNAL_PDF_VIEWER, CMD_VIEW_PDF_INTERNAL);
-			CommandInfo &ci = registerCommand(QString("user%1").arg(i), "", deprecatedUserToolNames[i], "", "", 0, true);
+            CommandInfo &ci = registerCommand(QString("user%1").arg(i), "", deprecatedUserToolNames[i], "", "", nullptr, true);
 			ci.commandLine = cmd;
 			userToolOrder << ci.id;
 			userToolDisplayNames << ci.displayName;
@@ -1381,7 +1390,7 @@ void BuildManager::readSettings(QSettings &settings)
 		QString temp = settings.value(QString("User/Tool%1").arg(i), "").toString();
 		if (!temp.isEmpty()) {
 			temp.replace(DEPRECACTED_TMX_INTERNAL_PDF_VIEWER, CMD_VIEW_PDF_INTERNAL);
-			CommandInfo &ci = registerCommand(QString("userold%1").arg(i), "", settings.value(QString("User/ToolName%1").arg(i)).toString(), "", "", 0, true);
+            CommandInfo &ci = registerCommand(QString("userold%1").arg(i), "", settings.value(QString("User/ToolName%1").arg(i)).toString(), "", "", nullptr, true);
 			ci.commandLine  = temp;
 			userToolOrder << ci.id;
 			userToolDisplayNames << ci.displayName;
@@ -1596,13 +1605,13 @@ ProcessX *BuildManager::firstProcessOfDirectExpansion(const QString &command, co
         options.nestingDeep=1; // tweak to avoid pop-up error messages
     }
 	ExpandedCommands expansion = expandCommandLine(command, options);
-	if (options.canceled) return 0;
+    if (options.canceled) return nullptr;
 
-	if (expansion.commands.isEmpty()) return 0;
+    if (expansion.commands.isEmpty()) { return nullptr; }
 
     foreach(CommandToRun elem,expansion.commands){
         if(elem.command.isEmpty()){
-            return 0; // error in command expansion
+            return nullptr; // error in command expansion
         }
 
     }
@@ -1614,7 +1623,7 @@ ProcessX *BuildManager::firstProcessOfDirectExpansion(const QString &command, co
 ProcessX *BuildManager::newProcessInternal(const QString &cmd, const QFileInfo &mainFile, bool singleInstance)
 {
 	if (singleInstance && runningCommands.contains(cmd))
-		return 0;
+        return nullptr;
 
 	ProcessX *proc = new ProcessX(this, cmd, mainFile.absoluteFilePath());
 	connect(proc, SIGNAL(processNotification(QString)), SIGNAL(processNotification(QString)));
@@ -1650,7 +1659,7 @@ bool BuildManager::waitForProcess(ProcessX *p)
 	}
 	QApplication::restoreOverrideCursor();
 	bool result = processWaitedFor;
-	processWaitedFor = 0;
+    processWaitedFor = nullptr;
 	m_stopBuildAction->setEnabled(false);
 	return result;
 }
@@ -1664,7 +1673,7 @@ void BuildManager::killCurrentProcess()
 {
 	if (!processWaitedFor) return;
 	processWaitedFor->kill();
-	processWaitedFor = 0;
+    processWaitedFor = nullptr;
 }
 
 QString BuildManager::createTemporaryFileName()
@@ -1752,7 +1761,7 @@ void BuildManager::preview(const QString &preamble, const PreviewSource &source,
 				QFileInfo fi(*tf);
 				preambleFormatFile = fi.completeBaseName();
 				previewFileNames.append(fi.absoluteFilePath());
-				ProcessX *p = 0;
+                ProcessX *p = nullptr;
 				if (dvi2pngMode == DPM_EMBEDDED_PDF) {
 					p = newProcessInternal(QString("%1 -interaction=nonstopmode -ini \"&pdflatex %3 \\dump\"").arg(getCommandInfo(CMD_PDFLATEX).getProgramName()).arg(preambleFormatFile), tf->fileName()); //no delete! goes automatically
 				} else {
@@ -1805,7 +1814,7 @@ void BuildManager::preview(const QString &preamble, const PreviewSource &source,
 	tf->setAutoRemove(false);
 	tf->close();
 	delete tf; // tex file needs to be freed
-	ProcessX *p1 = 0;
+    ProcessX *p1 = nullptr;
 	if (dvi2pngMode == DPM_EMBEDDED_PDF) {
 		// start conversion
 		// tex -> dvi
@@ -1877,7 +1886,7 @@ QString BuildManager::editCommandList(const QString &list, const QString &exclud
 		if (!ids[i].startsWith(TXS_CMD_PREFIX)) ids[i] = TXS_CMD_PREFIX + ids[i];
 	}
 
-	UserQuickDialog uqd(0, ids, names, commands);
+    UserQuickDialog uqd(nullptr, ids, names, commands);
 	uqd.setCommandList(list);
 	if (uqd.exec() == QDialog::Accepted) return uqd.getCommandList();
 	else return list;
@@ -2082,7 +2091,10 @@ bool BuildManager::testAndRunInternalCommand(const QString &cmd, const QFileInfo
 	int space = cmd.indexOf(' ');
 	QString cmdId, options;
 	if (space == -1 ) cmdId = cmd;
-	else cmdId = cmd.left(space), options = cmd.mid(space + 1);
+    else {
+        cmdId = cmd.left(space);
+        options = cmd.mid(space + 1);
+    }
 	if (internalCommands.contains(cmdId)) {
 		emit runInternalCommand(cmdId, mainFile, options);
 		return true;
@@ -2223,7 +2235,7 @@ bool BuildManager::executeDDE(QString ddePseudoURL)
 #endif
 
 ProcessX::ProcessX(BuildManager *parent, const QString &assignedCommand, const QString &fileToCompile):
-	QProcess(parent), cmd(assignedCommand.trimmed()), file(fileToCompile), isStarted(false), ended(false), stderrEnabled(true), stdoutEnabled(true), stdoutEnabledOverrideOn(false), stdoutBuffer(0), stdoutCodec(0)
+    QProcess(parent), cmd(assignedCommand.trimmed()), file(fileToCompile), isStarted(false), ended(false), stderrEnabled(true), stdoutEnabled(true), stdoutEnabledOverrideOn(false), stdoutBuffer(nullptr), stdoutCodec(nullptr)
 {
 
 	QString stdoutRedirection, stderrRedirection;
