@@ -10,7 +10,7 @@
 QEditorTest::QEditorTest(QEditor* ed, bool executeAllTests):allTests(executeAllTests)
 {
 	editor=ed;
-	if (editor->getFileCodec()!=0) defaultCodec = editor->getFileCodec();
+    if (editor->getFileCodec()!=nullptr) defaultCodec = editor->getFileCodec();
 	else defaultCodec = QTextCodec::codecForName("latin1");
 	ed->setFlag(QEditor::HardLineWrap, false);
 	ed->setFlag(QEditor::AutoCloseChars, true);
@@ -83,7 +83,7 @@ void QEditorTest::loadSave(){
 
 	//Load
 	editor->setFileCodec(QTextCodec::codecForName("iso-8859-5"));
-	editor->load(tfn,autodetect?0:outCodec);
+    editor->load(tfn,autodetect?nullptr:outCodec);
 	editor->document()->setLineEnding(editor->document()->originalLineEnding()); //TODO: find out why this line is only needed iff the editor passed by the testmanager is used and not if a new QEditor(0) is created
     QEQUAL2(editor->document()->text(),testTextWithLineEndings,QString("File: %1  Got file codec: %2 ").arg(tfn).arg(editor->getFileCodec()?QString::fromLatin1(editor->getFileCodec()->name()):"<null>"));
     QVERIFY2(editor->getFileCodec()==outCodec,qPrintable(QString("wrong encoding: got %1 wanted %2 by the sheriff %3").arg(QString::fromLatin1(editor->getFileCodec()->name())).arg(QString::fromLatin1(outCodec->name())).arg(autodetect)));
@@ -93,9 +93,11 @@ void QEditorTest::loadSave(){
 	editor->setText(editor->document()->text()+"Save test", false);
 	editor->save();
     QFile tf2(tfn);
-    tf2.open(QIODevice::ReadOnly);
-    QString writtenText=outCodec->toUnicode( tf2.readAll());
-    tf2.close();
+    QString writtenText;
+    if(tf2.open(QIODevice::ReadOnly)){
+        writtenText=outCodec->toUnicode( tf2.readAll());
+        tf2.close();
+    }
 
 	QEQUAL2(writtenText, testTextWithLineEndings+"Save test", "file text check, file:"+tfn);
 	QVERIFY2(writtenText.contains(outLineEnding), qPrintable("file don't contain right line ending, file"+tfn));
@@ -813,11 +815,12 @@ void QEditorTest::autoClosing_data(){
 	QTest::newRow("counting 1") << ">())<" << 0 << 1 << "(" << ">(())<";
 	QTest::newRow("counting 2") << ">((())))<" << 0 << 1 << "(" << ">(((())))<";
 	QTest::newRow("counting 3") << ">((()()))())<" << 0 << 1 << "(" << ">(((()()))())<";
-	QTest::newRow("multi line search") << ">\n\n\\]<" << 0 << 1 << "\\[" << ">\\[\n\n\\]<";
+    QTest::newRow("counting 4") << ">(())<" << 0 << 4 << "(" << ">(()())<";
+    QTest::newRow("multi line search") << ">\n\n)<" << 0 << 1 << "(" << ">(\n\n)<";
 	QTest::newRow("insert-match-to-close-mixed") << ">[{}])<" << 0 << 1 << "(" << ">([{}])<";
 	QTest::newRow("insert-match-to-close-mixed-with-same") << ">([{}]))<" << 0 << 1 << "(" << ">(([{}]))<";
 	QTest::newRow("insert-match-to-close-mixed-with-same2") << ">([{}]))<" << 0 << 2 << "(" << ">(([{}]))<";
-	QTest::newRow("many") << "(((((())))))" << 0 << 1 << "(" << "((((((())))))";
+    QTest::newRow("many") << "(((((())))))" << 0 << 1 << "(" << "(()((((())))))"; // previous expected outcome was unlogical, why not autocomlete if all parentehsis prior already match ?
 	QTest::newRow("following") << " ()" << 0 << 0 << "(" << "() ()";
 	QTest::newRow("following2") << " \\(\\)" << 0 << 0 << "\\(" << "\\(\\) \\(\\)";
 	QTest::newRow("following2withExistingMismatch") << " {\\(\\)" << 0 << 0 << "\\(" << "\\(\\) {\\(\\)";
